// Copyright (C) 2022 - 2023, Xilinx Inc - All rights reserved
//
// Licensed under the Apache License, Version 2.0 (the "License"). You may
// not use this file except in compliance with the License. A copy of the
// License is located at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
// WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
// License for the specific language governing permissions and limitations
// under the License.

#ifndef _XRM_ENC_INTERFACE_H_
#define _XRM_ENC_INTERFACE_H_
#ifdef __cplusplus
extern "C" {
#endif

#include <xrm.h>
#include "xrm_interface.h"

#define XRM_HEVC_ENC "ENCODER"

/* See https://confluence.xilinx.com/display/VDC/XRM+host+plugins for diagram 
showing slice layout */
typedef enum { XAV1_SLICE_0 = 0, VC8000E_SLICE_0 = 1, XAV1_SLICE_1 = 2, VC8000E_SLICE_1 = 3 } XRM_ENCODER_GROUP_IDs;

typedef struct {
  int                 dev_index;
  int                 slice_id;
  xrmContext          xrm_ctx;
  xrmCuListResourceV2 encode_cu_list_res;
  int32_t             xrm_reserve_id;
  int32_t             enc_res_in_use;
  int                 enc_load[3]; // is_xav1 flag, encoder load & lookahead load
} XrmEncodeContext;

/**
 * @brief Release the xrm resources which were allocated. Destroy the xrm
 * context.
 * 
 * @param xrm_enc_ctx: Encoder XRM context
 * @return None
 */
void xrm_enc_release(XrmEncodeContext* xrm_enc_ctx);

/**
 * @brief Check & allocate the necessary xrm resources given the relevant 
 * encoder parameters
 * 
 * @param xrm_enc_ctx Used to store information about resources this function
 * allocates so they can be safely released later
 * @param dev_index The device index
 * @param slice_id The slice index. -1 for xrm to choose the slice, otherwise
 * 0 or 1
 * @param is_av1 Is the codec to be used xav1 or not
 * @param is_ull Is ultra low latency enabled or not
 * @param xrm_props Contains relevant information for load calculation
 * @return XRM_SUCCESS on success, XRM_ERROR on error or XRM_ERROR_CONNECT_FAIL
 * when unable to connect to daemon
 */
int32_t xrm_enc_reserve(XrmEncodeContext* xrm_enc_ctx, int dev_index, int slice_id, bool is_xav1, bool is_ull, XrmInterfaceProperties* xrm_props);
#ifdef __cplusplus
}
#endif
#endif // _XRM_ENC_INTERFACE_H_
